@@ -2,7 +2,7 @@ package Analizo::Batch::Directories;
 use strict;
 use warnings;
 
-use base qw(Analizo::Batch Class::Accessor::Fast);
+use parent qw(Analizo::Batch Class::Accessor::Fast);
 use Analizo::Batch::Job::Directories;
 
 __PACKAGE__->mk_accessors(qw(directories));
@@ -23,7 +23,7 @@ sub fetch_next {
   my ($self) = @_;
   my $next_directory = $self->{directories}->[$self->{index}];
   if ($next_directory) {
-    my $next_job = new Analizo::Batch::Job::Directories($next_directory);
+    my $next_job = Analizo::Batch::Job::Directories->new($next_directory);
     $self->{index} += 1;
     return $next_job;
   }
